System

Struct System 

pub struct System {
    pub forward: AxisDirectionPair,
    pub up: AxisDirectionPair,
}
Co-ordinate system definition.

The up axis must be orthogonal to the forward axis.

See [cglearn.eu] for background reading.

cglearn.eu

Fields

forward: AxisDirectionPair

Axis the front face of a model looks along.

up: AxisDirectionPair

Axis pointing up and away from a model.