pub struct BooleanUnionBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> BooleanUnionBuilder<S>
impl<S: State> BooleanUnionBuilder<S>
Sourcepub fn build(self) -> BooleanUnionwhere
S: IsComplete,
pub fn build(self) -> BooleanUnionwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn solid_ids(self, value: Vec<Uuid>) -> BooleanUnionBuilder<SetSolidIds<S>>where
S::SolidIds: IsUnset,
pub fn solid_ids(self, value: Vec<Uuid>) -> BooleanUnionBuilder<SetSolidIds<S>>where
S::SolidIds: IsUnset,
Required.
Which solids to union together. Cannot be empty.
Sourcepub fn separate_bodies(
self,
value: bool,
) -> BooleanUnionBuilder<SetSeparateBodies<S>>where
S::SeparateBodies: IsUnset,
pub fn separate_bodies(
self,
value: bool,
) -> BooleanUnionBuilder<SetSeparateBodies<S>>where
S::SeparateBodies: IsUnset,
Sourcepub fn maybe_separate_bodies(
self,
value: Option<bool>,
) -> BooleanUnionBuilder<SetSeparateBodies<S>>where
S::SeparateBodies: IsUnset,
pub fn maybe_separate_bodies(
self,
value: Option<bool>,
) -> BooleanUnionBuilder<SetSeparateBodies<S>>where
S::SeparateBodies: IsUnset,
Sourcepub fn use_legacy(self, value: bool) -> BooleanUnionBuilder<SetUseLegacy<S>>where
S::UseLegacy: IsUnset,
pub fn use_legacy(self, value: bool) -> BooleanUnionBuilder<SetUseLegacy<S>>where
S::UseLegacy: IsUnset,
Sourcepub fn maybe_use_legacy(
self,
value: Option<bool>,
) -> BooleanUnionBuilder<SetUseLegacy<S>>where
S::UseLegacy: IsUnset,
pub fn maybe_use_legacy(
self,
value: Option<bool>,
) -> BooleanUnionBuilder<SetUseLegacy<S>>where
S::UseLegacy: IsUnset,
Sourcepub fn tolerance(
self,
value: LengthUnit,
) -> BooleanUnionBuilder<SetTolerance<S>>where
S::Tolerance: IsUnset,
pub fn tolerance(
self,
value: LengthUnit,
) -> BooleanUnionBuilder<SetTolerance<S>>where
S::Tolerance: IsUnset,
Required.
The maximum acceptable surface gap computed between the joined solids. Must be positive (i.e. greater than zero).