CreateRegionBuilder

Struct CreateRegionBuilder 

pub struct CreateRegionBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CreateRegionBuilder<S>

pub fn build(self) -> CreateRegion
where S: IsComplete,

Finish building and return the requested object

pub fn object_id(self, value: Uuid) -> CreateRegionBuilder<SetObjectId<S>>
where S::ObjectId: IsUnset,

Required.

Which sketch object to create the region from.

pub fn segment(self, value: Uuid) -> CreateRegionBuilder<SetSegment<S>>
where S::Segment: IsUnset,

Required.

First segment to follow to find the region.

pub fn intersection_segment( self, value: Uuid, ) -> CreateRegionBuilder<SetIntersectionSegment<S>>
where S::IntersectionSegment: IsUnset,

Required.

Second segment to follow to find the region. Intersects the first segment.

pub fn intersection_index( self, value: i32, ) -> CreateRegionBuilder<SetIntersectionIndex<S>>
where S::IntersectionIndex: IsUnset,

Optional (Some / Option setters). Default: super::negative_one().

At which intersection between segment and intersection_segment should we stop following the segment and start following intersection_segment? Defaults to -1, which means the last intersection.

pub fn maybe_intersection_index( self, value: Option<i32>, ) -> CreateRegionBuilder<SetIntersectionIndex<S>>
where S::IntersectionIndex: IsUnset,

Optional (Some / Option setters). Default: super::negative_one().

At which intersection between segment and intersection_segment should we stop following the segment and start following intersection_segment? Defaults to -1, which means the last intersection.

pub fn curve_clockwise( self, value: bool, ) -> CreateRegionBuilder<SetCurveClockwise<S>>
where S::CurveClockwise: IsUnset,

Optional (Some / Option setters). Default: false.

By default, curve counterclockwise at intersections. If this is true, instead curve clockwise.

pub fn maybe_curve_clockwise( self, value: Option<bool>, ) -> CreateRegionBuilder<SetCurveClockwise<S>>
where S::CurveClockwise: IsUnset,

Optional (Some / Option setters). Default: false.

By default, curve counterclockwise at intersections. If this is true, instead curve clockwise.

pub fn version(self, value: RegionVersion) -> CreateRegionBuilder<SetVersion<S>>
where S::Version: IsUnset,

Optional (Some / Option setters). Default: <RegionVersion as Default>::default().

Which version of the Region endpoint to call.

pub fn maybe_version( self, value: Option<RegionVersion>, ) -> CreateRegionBuilder<SetVersion<S>>
where S::Version: IsUnset,

Optional (Some / Option setters). Default: <RegionVersion as Default>::default().

Which version of the Region endpoint to call.