pub struct CreateRegionFromQueryPointBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> CreateRegionFromQueryPointBuilder<S>
impl<S: State> CreateRegionFromQueryPointBuilder<S>
Sourcepub fn build(self) -> CreateRegionFromQueryPointwhere
S: IsComplete,
pub fn build(self) -> CreateRegionFromQueryPointwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn object_id(
self,
value: Uuid,
) -> CreateRegionFromQueryPointBuilder<SetObjectId<S>>where
S::ObjectId: IsUnset,
pub fn object_id(
self,
value: Uuid,
) -> CreateRegionFromQueryPointBuilder<SetObjectId<S>>where
S::ObjectId: IsUnset,
Required.
Which sketch object to create the region from.
Sourcepub fn query_point(
self,
value: Point2d<LengthUnit>,
) -> CreateRegionFromQueryPointBuilder<SetQueryPoint<S>>where
S::QueryPoint: IsUnset,
pub fn query_point(
self,
value: Point2d<LengthUnit>,
) -> CreateRegionFromQueryPointBuilder<SetQueryPoint<S>>where
S::QueryPoint: IsUnset,
Required.
The query point (in the same coordinates as the sketch itself) if a possible sketch region contains this point, then that region will be created
Sourcepub fn version(
self,
value: RegionVersion,
) -> CreateRegionFromQueryPointBuilder<SetVersion<S>>where
S::Version: IsUnset,
pub fn version(
self,
value: RegionVersion,
) -> CreateRegionFromQueryPointBuilder<SetVersion<S>>where
S::Version: IsUnset,
Sourcepub fn maybe_version(
self,
value: Option<RegionVersion>,
) -> CreateRegionFromQueryPointBuilder<SetVersion<S>>where
S::Version: IsUnset,
pub fn maybe_version(
self,
value: Option<RegionVersion>,
) -> CreateRegionFromQueryPointBuilder<SetVersion<S>>where
S::Version: IsUnset,