pub struct NewAnnotationBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> NewAnnotationBuilder<S>
impl<S: State> NewAnnotationBuilder<S>
Sourcepub fn build(self) -> NewAnnotationwhere
S: IsComplete,
pub fn build(self) -> NewAnnotationwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn options(
self,
value: AnnotationOptions,
) -> NewAnnotationBuilder<SetOptions<S>>where
S::Options: IsUnset,
pub fn options(
self,
value: AnnotationOptions,
) -> NewAnnotationBuilder<SetOptions<S>>where
S::Options: IsUnset,
Required.
What should the annotation contain?
Sourcepub fn clobber(self, value: bool) -> NewAnnotationBuilder<SetClobber<S>>where
S::Clobber: IsUnset,
pub fn clobber(self, value: bool) -> NewAnnotationBuilder<SetClobber<S>>where
S::Clobber: IsUnset,
Required.
If true, any existing drawables within the obj will be replaced (the object will be reset)
Sourcepub fn annotation_type(
self,
value: AnnotationType,
) -> NewAnnotationBuilder<SetAnnotationType<S>>where
S::AnnotationType: IsUnset,
pub fn annotation_type(
self,
value: AnnotationType,
) -> NewAnnotationBuilder<SetAnnotationType<S>>where
S::AnnotationType: IsUnset,
Required.
What type of annotation to create.