pub struct KclProjectBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> KclProjectBuilder<S>
impl<S: State> KclProjectBuilder<S>
Sourcepub fn build(self) -> KclProjectwhere
S: IsComplete,
pub fn build(self) -> KclProjectwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn files(self, value: Vec<KclFile>) -> KclProjectBuilder<SetFiles<S>>where
S::Files: IsUnset,
pub fn files(self, value: Vec<KclFile>) -> KclProjectBuilder<SetFiles<S>>where
S::Files: IsUnset,
Required.
All files in the project.
Sourcepub fn entrypoint(
self,
value: SafeFilepath,
) -> KclProjectBuilder<SetEntrypoint<S>>where
S::Entrypoint: IsUnset,
pub fn entrypoint(
self,
value: SafeFilepath,
) -> KclProjectBuilder<SetEntrypoint<S>>where
S::Entrypoint: IsUnset,
Required.
Which file is the entrypoint? This is the first KCL file to be executed, the root of the KCL module tree.