pub enum Presentation {
Compact,
Pretty,
}Expand description
Describes the presentation style of the EXPRESS exchange format.
Variants
Compact
Condenses the text to reduce the size of the file.
Pretty
Add extra spaces to make the text more easily readable.
This is the default setting.