pub struct CreateRegionFromQueryPoint {
pub region_mapping: HashMap<Uuid, Uuid>,
}Expand description
The response from the ‘CreateRegionFromQueryPoint’. The region should have an ID taken from the ID of the ‘CreateRegionFromQueryPoint’ modeling command.
Fields
region_mapping: HashMap<Uuid, Uuid>a mapping from the curves within this region to the source component segment curves they were split from