pub enum MirrorAcross {
Edge {
id: Uuid,
},
Axis {
axis: Point3d<f64>,
point: Point3d<LengthUnit>,
},
Plane {
id: Uuid,
},
}Expand description
What to reflect mirrored geometry across
Variants
Edge
Reflect across an edge If used with a 3D mirror, the edge will define the normal of the mirror plane.
Axis
Reflect across an axis (that goes through a point) If used with a 3D mirror, the axis will define the normal of the mirror plane.
Fields

point: Point3d<LengthUnit>Point through which the mirror axis passes.
Plane
Reflect across a plane (which gives two axes) Cannot be used with 2D mirrors.