pub enum RegionVersion {
V0,
V1,
}Expand description
Region-creation algorithm version.
Variants
V0
The original region creation method. This should NOT be used anymore, but is maintained to avoid breaking old models.
V1
Fixes the bug in V0 where creating a region would shuffle the mapping from segment names/IDs to actual segment geometry.
Implementations