AnnotationBasicDimensionBuilder

Struct AnnotationBasicDimensionBuilder 

pub struct AnnotationBasicDimensionBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> AnnotationBasicDimensionBuilder<S>

pub fn build(self) -> AnnotationBasicDimension
where S: IsComplete,

Finish building and return the requested object

pub fn from_entity_id( self, value: Uuid, ) -> AnnotationBasicDimensionBuilder<SetFromEntityId<S>>
where S::FromEntityId: IsUnset,

Required.

Entity to measure the dimension from

pub fn from_entity_pos( self, value: Point2d<f64>, ) -> AnnotationBasicDimensionBuilder<SetFromEntityPos<S>>
where S::FromEntityPos: IsUnset,

Required.

Normalized position within the entity to position the dimension from

pub fn to_entity_id( self, value: Uuid, ) -> AnnotationBasicDimensionBuilder<SetToEntityId<S>>
where S::ToEntityId: IsUnset,

Required.

Entity to measure the dimension to

pub fn to_entity_pos( self, value: Point2d<f64>, ) -> AnnotationBasicDimensionBuilder<SetToEntityPos<S>>
where S::ToEntityPos: IsUnset,

Required.

Normalized position within the entity to position the dimension to

pub fn dimension( self, value: AnnotationMbdBasicDimension, ) -> AnnotationBasicDimensionBuilder<SetDimension<S>>
where S::Dimension: IsUnset,

Required.

Basic dimension parameters (symbol and tolerance)

pub fn plane_id( self, value: Uuid, ) -> AnnotationBasicDimensionBuilder<SetPlaneId<S>>
where S::PlaneId: IsUnset,

Required.

Orientation plane. The annotation will lie in this plane which is positioned about the leader position as its origin.

pub fn offset( self, value: Point2d<f64>, ) -> AnnotationBasicDimensionBuilder<SetOffset<S>>
where S::Offset: IsUnset,

Required.

2D Position offset of the annotation within the plane.

pub fn precision( self, value: u32, ) -> AnnotationBasicDimensionBuilder<SetPrecision<S>>
where S::Precision: IsUnset,

Required.

Number of decimal places to use when displaying tolerance and dimension values

pub fn font_scale( self, value: f32, ) -> AnnotationBasicDimensionBuilder<SetFontScale<S>>
where S::FontScale: IsUnset,

Required.

The scale of the font label in 3D space

pub fn font_point_size( self, value: u32, ) -> AnnotationBasicDimensionBuilder<SetFontPointSize<S>>
where S::FontPointSize: IsUnset,

Required.

The point size of the fonts used to generate the annotation label. Very large values can negatively affect performance.

pub fn arrow_scale( self, value: f32, ) -> AnnotationBasicDimensionBuilder<SetArrowScale<S>>
where S::ArrowScale: IsUnset,

Required.

The scale of the dimension arrows. Defaults to 1.