AnnotationFeatureControlBuilder

Struct AnnotationFeatureControlBuilder 

pub struct AnnotationFeatureControlBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> AnnotationFeatureControlBuilder<S>

pub fn build(self) -> AnnotationFeatureControl
where S: IsComplete,

Finish building and return the requested object

pub fn entity_id( self, value: Uuid, ) -> AnnotationFeatureControlBuilder<SetEntityId<S>>
where S::EntityId: IsUnset,

Required.

Entity to place the annotation leader from

pub fn entity_pos( self, value: Point2d<f64>, ) -> AnnotationFeatureControlBuilder<SetEntityPos<S>>
where S::EntityPos: IsUnset,

Required.

Normalized position within the entity to position the annotation leader from

pub fn leader_type( self, value: AnnotationLineEnd, ) -> AnnotationFeatureControlBuilder<SetLeaderType<S>>
where S::LeaderType: IsUnset,

Required.

Type of leader to use

pub fn dimension( self, value: AnnotationMbdBasicDimension, ) -> AnnotationFeatureControlBuilder<SetDimension<S>>
where S::Dimension: IsUnset,

Optional (Some / Option setters). Basic dimensions

pub fn maybe_dimension( self, value: Option<AnnotationMbdBasicDimension>, ) -> AnnotationFeatureControlBuilder<SetDimension<S>>
where S::Dimension: IsUnset,

Optional (Some / Option setters). Basic dimensions

pub fn control_frame( self, value: AnnotationMbdControlFrame, ) -> AnnotationFeatureControlBuilder<SetControlFrame<S>>
where S::ControlFrame: IsUnset,

Optional (Some / Option setters). MBD Control frame for geometric control

pub fn maybe_control_frame( self, value: Option<AnnotationMbdControlFrame>, ) -> AnnotationFeatureControlBuilder<SetControlFrame<S>>
where S::ControlFrame: IsUnset,

Optional (Some / Option setters). MBD Control frame for geometric control

pub fn defined_datum( self, value: char, ) -> AnnotationFeatureControlBuilder<SetDefinedDatum<S>>
where S::DefinedDatum: IsUnset,

Optional (Some / Option setters). Set if this annotation is defining a datum

pub fn maybe_defined_datum( self, value: Option<char>, ) -> AnnotationFeatureControlBuilder<SetDefinedDatum<S>>
where S::DefinedDatum: IsUnset,

Optional (Some / Option setters). Set if this annotation is defining a datum

pub fn prefix( self, value: String, ) -> AnnotationFeatureControlBuilder<SetPrefix<S>>
where S::Prefix: IsUnset,

Optional (Some / Option setters). Prefix text which will appear before the basic dimension

pub fn maybe_prefix( self, value: Option<String>, ) -> AnnotationFeatureControlBuilder<SetPrefix<S>>
where S::Prefix: IsUnset,

Optional (Some / Option setters). Prefix text which will appear before the basic dimension

pub fn suffix( self, value: String, ) -> AnnotationFeatureControlBuilder<SetSuffix<S>>
where S::Suffix: IsUnset,

Optional (Some / Option setters). Suffix text which will appear after the basic dimension

pub fn maybe_suffix( self, value: Option<String>, ) -> AnnotationFeatureControlBuilder<SetSuffix<S>>
where S::Suffix: IsUnset,

Optional (Some / Option setters). Suffix text which will appear after the basic dimension

pub fn plane_id( self, value: Uuid, ) -> AnnotationFeatureControlBuilder<SetPlaneId<S>>
where S::PlaneId: IsUnset,

Required.

Orientation plane. The annotation will lie in this plane which is positioned about the leader position as its origin.

pub fn offset( self, value: Point2d<f64>, ) -> AnnotationFeatureControlBuilder<SetOffset<S>>
where S::Offset: IsUnset,

Required.

2D Position offset of the annotation within the plane.

pub fn precision( self, value: u32, ) -> AnnotationFeatureControlBuilder<SetPrecision<S>>
where S::Precision: IsUnset,

Required.

Number of decimal places to use when displaying tolerance and dimension values

pub fn font_scale( self, value: f32, ) -> AnnotationFeatureControlBuilder<SetFontScale<S>>
where S::FontScale: IsUnset,

Required.

The scale of the font label in 3D space

pub fn font_point_size( self, value: u32, ) -> AnnotationFeatureControlBuilder<SetFontPointSize<S>>
where S::FontPointSize: IsUnset,

Required.

The point size of the fonts used to generate the annotation label. Very large values can negatively affect performance.

pub fn leader_scale( self, value: f32, ) -> AnnotationFeatureControlBuilder<SetLeaderScale<S>>
where S::LeaderScale: IsUnset,

Required.

The scale of the leader (dot or arrow). Defaults to 1.