pub struct AnnotationFeatureTag {
pub entity_id: Option<Uuid>,
pub edge_reference: Option<EdgeSpecifier>,
pub entity_pos: Point2d<f64>,
pub leader_type: AnnotationLineEnd,
pub key: String,
pub value: String,
pub show_key: bool,
pub plane_id: Uuid,
pub offset: Point2d<f64>,
pub font_scale: f32,
pub font_point_size: u32,
pub leader_scale: f32,
}Expand description
Parameters for defining an MBD Feature Tag Annotation state
Fields
entity_id: Option<Uuid>Entity to place the annotation leader from
edge_reference: Option<EdgeSpecifier>Edge reference to use to place the annotation leader from
If both entity_id and edge_reference are provided, edge_reference takes precedence.
entity_pos: Point2d<f64>Normalized position within the entity to position the annotation leader from
leader_type: AnnotationLineEndType of leader to use
key: StringTag key
value: StringTag value
show_key: boolWhether or not to display the key on the annotation label
plane_id: UuidOrientation plane. The annotation will lie in this plane which is positioned about the leader position as its origin.
offset: Point2d<f64>2D Position offset of the annotation within the plane.
font_scale: f32The scale of the font label in 3D space
font_point_size: u32The point size of the fonts used to generate the annotation label. Very large values can negatively affect performance.
leader_scale: f32The scale of the leader (dot or arrow). Defaults to 1.
Implementations
Sourceimpl AnnotationFeatureTag
impl AnnotationFeatureTag
Sourcepub fn builder() -> AnnotationFeatureTagBuilder
pub fn builder() -> AnnotationFeatureTagBuilder
Create an instance of AnnotationFeatureTag using the builder syntax