AnnotationMbdControlFrameBuilder

Struct AnnotationMbdControlFrameBuilder 

pub struct AnnotationMbdControlFrameBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> AnnotationMbdControlFrameBuilder<S>

pub fn build(self) -> AnnotationMbdControlFrame
where S: IsComplete,

Finish building and return the requested object

pub fn symbol( self, value: MbdSymbol, ) -> AnnotationMbdControlFrameBuilder<SetSymbol<S>>
where S::Symbol: IsUnset,

Required.

Geometric symbol, the type of geometric control specified

pub fn diameter_symbol( self, value: MbdSymbol, ) -> AnnotationMbdControlFrameBuilder<SetDiameterSymbol<S>>
where S::DiameterSymbol: IsUnset,

Optional (Some / Option setters). Diameter symbol (if required) whether the geometric control requires a cylindrical or diameter tolerance

pub fn maybe_diameter_symbol( self, value: Option<MbdSymbol>, ) -> AnnotationMbdControlFrameBuilder<SetDiameterSymbol<S>>
where S::DiameterSymbol: IsUnset,

Optional (Some / Option setters). Diameter symbol (if required) whether the geometric control requires a cylindrical or diameter tolerance

pub fn tolerance( self, value: f64, ) -> AnnotationMbdControlFrameBuilder<SetTolerance<S>>
where S::Tolerance: IsUnset,

Required.

Tolerance value - the total tolerance of the geometric control. The unit is based on the drawing standard.

pub fn modifier( self, value: MbdSymbol, ) -> AnnotationMbdControlFrameBuilder<SetModifier<S>>
where S::Modifier: IsUnset,

Optional (Some / Option setters). Feature of size or tolerance modifiers

pub fn maybe_modifier( self, value: Option<MbdSymbol>, ) -> AnnotationMbdControlFrameBuilder<SetModifier<S>>
where S::Modifier: IsUnset,

Optional (Some / Option setters). Feature of size or tolerance modifiers

pub fn primary_datum( self, value: char, ) -> AnnotationMbdControlFrameBuilder<SetPrimaryDatum<S>>
where S::PrimaryDatum: IsUnset,

Optional (Some / Option setters). Primary datum

pub fn maybe_primary_datum( self, value: Option<char>, ) -> AnnotationMbdControlFrameBuilder<SetPrimaryDatum<S>>
where S::PrimaryDatum: IsUnset,

Optional (Some / Option setters). Primary datum

pub fn secondary_datum( self, value: char, ) -> AnnotationMbdControlFrameBuilder<SetSecondaryDatum<S>>
where S::SecondaryDatum: IsUnset,

Optional (Some / Option setters). Secondary datum

pub fn maybe_secondary_datum( self, value: Option<char>, ) -> AnnotationMbdControlFrameBuilder<SetSecondaryDatum<S>>
where S::SecondaryDatum: IsUnset,

Optional (Some / Option setters). Secondary datum

pub fn tertiary_datum( self, value: char, ) -> AnnotationMbdControlFrameBuilder<SetTertiaryDatum<S>>
where S::TertiaryDatum: IsUnset,

Optional (Some / Option setters). Tertiary datum

pub fn maybe_tertiary_datum( self, value: Option<char>, ) -> AnnotationMbdControlFrameBuilder<SetTertiaryDatum<S>>
where S::TertiaryDatum: IsUnset,

Optional (Some / Option setters). Tertiary datum