AnnotationOptionsBuilder

Struct AnnotationOptionsBuilder 

pub struct AnnotationOptionsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> AnnotationOptionsBuilder<S>

pub fn build(self) -> AnnotationOptions
where S: IsComplete,

Finish building and return the requested object

pub fn text( self, value: AnnotationTextOptions, ) -> AnnotationOptionsBuilder<SetText<S>>
where S::Text: IsUnset,

Optional (Some / Option setters). Text displayed on the annotation

pub fn maybe_text( self, value: Option<AnnotationTextOptions>, ) -> AnnotationOptionsBuilder<SetText<S>>
where S::Text: IsUnset,

Optional (Some / Option setters). Text displayed on the annotation

pub fn line_ends( self, value: AnnotationLineEndOptions, ) -> AnnotationOptionsBuilder<SetLineEnds<S>>
where S::LineEnds: IsUnset,

Optional (Some / Option setters). How to style the start and end of the line

pub fn maybe_line_ends( self, value: Option<AnnotationLineEndOptions>, ) -> AnnotationOptionsBuilder<SetLineEnds<S>>
where S::LineEnds: IsUnset,

Optional (Some / Option setters). How to style the start and end of the line

pub fn line_width(self, value: f32) -> AnnotationOptionsBuilder<SetLineWidth<S>>
where S::LineWidth: IsUnset,

Optional (Some / Option setters). Width of the annotation’s line

pub fn maybe_line_width( self, value: Option<f32>, ) -> AnnotationOptionsBuilder<SetLineWidth<S>>
where S::LineWidth: IsUnset,

Optional (Some / Option setters). Width of the annotation’s line

pub fn color(self, value: Color) -> AnnotationOptionsBuilder<SetColor<S>>
where S::Color: IsUnset,

Optional (Some / Option setters). Color to render the annotation

pub fn maybe_color( self, value: Option<Color>, ) -> AnnotationOptionsBuilder<SetColor<S>>
where S::Color: IsUnset,

Optional (Some / Option setters). Color to render the annotation

pub fn position( self, value: Point3d<f32>, ) -> AnnotationOptionsBuilder<SetPosition<S>>
where S::Position: IsUnset,

Optional (Some / Option setters). Position to put the annotation

pub fn maybe_position( self, value: Option<Point3d<f32>>, ) -> AnnotationOptionsBuilder<SetPosition<S>>
where S::Position: IsUnset,

Optional (Some / Option setters). Position to put the annotation

pub fn dimension( self, value: AnnotationBasicDimension, ) -> AnnotationOptionsBuilder<SetDimension<S>>
where S::Dimension: IsUnset,

Optional (Some / Option setters). Set as an MBD measured basic dimension annotation

pub fn maybe_dimension( self, value: Option<AnnotationBasicDimension>, ) -> AnnotationOptionsBuilder<SetDimension<S>>
where S::Dimension: IsUnset,

Optional (Some / Option setters). Set as an MBD measured basic dimension annotation

pub fn feature_control( self, value: AnnotationFeatureControl, ) -> AnnotationOptionsBuilder<SetFeatureControl<S>>
where S::FeatureControl: IsUnset,

Optional (Some / Option setters). Set as an MBD Feature control annotation

pub fn maybe_feature_control( self, value: Option<AnnotationFeatureControl>, ) -> AnnotationOptionsBuilder<SetFeatureControl<S>>
where S::FeatureControl: IsUnset,

Optional (Some / Option setters). Set as an MBD Feature control annotation

pub fn feature_tag( self, value: AnnotationFeatureTag, ) -> AnnotationOptionsBuilder<SetFeatureTag<S>>
where S::FeatureTag: IsUnset,

Optional (Some / Option setters). Set as a feature tag annotation

pub fn maybe_feature_tag( self, value: Option<AnnotationFeatureTag>, ) -> AnnotationOptionsBuilder<SetFeatureTag<S>>
where S::FeatureTag: IsUnset,

Optional (Some / Option setters). Set as a feature tag annotation