ComponentTransformBuilder

Struct ComponentTransformBuilder 

pub struct ComponentTransformBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ComponentTransformBuilder<S>

pub fn build(self) -> ComponentTransform
where S: IsComplete,

Finish building and return the requested object

pub fn translate( self, value: TransformBy<Point3d<LengthUnit>>, ) -> ComponentTransformBuilder<SetTranslate<S>>
where S::Translate: IsUnset,

Optional (Some / Option setters). Translate component of the transform.

pub fn maybe_translate( self, value: Option<TransformBy<Point3d<LengthUnit>>>, ) -> ComponentTransformBuilder<SetTranslate<S>>
where S::Translate: IsUnset,

Optional (Some / Option setters). Translate component of the transform.

pub fn rotate_rpy( self, value: TransformBy<Point3d<f64>>, ) -> ComponentTransformBuilder<SetRotateRpy<S>>
where S::RotateRpy: IsUnset,

Optional (Some / Option setters). Rotate component of the transform. The rotation is specified as a roll, pitch, yaw.

pub fn maybe_rotate_rpy( self, value: Option<TransformBy<Point3d<f64>>>, ) -> ComponentTransformBuilder<SetRotateRpy<S>>
where S::RotateRpy: IsUnset,

Optional (Some / Option setters). Rotate component of the transform. The rotation is specified as a roll, pitch, yaw.

pub fn rotate_angle_axis( self, value: TransformBy<Point4d<f64>>, ) -> ComponentTransformBuilder<SetRotateAngleAxis<S>>
where S::RotateAngleAxis: IsUnset,

Optional (Some / Option setters). Rotate component of the transform. The rotation is specified as an axis and an angle (xyz are the components of the axis, w is the angle in degrees).

pub fn maybe_rotate_angle_axis( self, value: Option<TransformBy<Point4d<f64>>>, ) -> ComponentTransformBuilder<SetRotateAngleAxis<S>>
where S::RotateAngleAxis: IsUnset,

Optional (Some / Option setters). Rotate component of the transform. The rotation is specified as an axis and an angle (xyz are the components of the axis, w is the angle in degrees).

pub fn scale( self, value: TransformBy<Point3d<f64>>, ) -> ComponentTransformBuilder<SetScale<S>>
where S::Scale: IsUnset,

Optional (Some / Option setters). Scale component of the transform.

pub fn maybe_scale( self, value: Option<TransformBy<Point3d<f64>>>, ) -> ComponentTransformBuilder<SetScale<S>>
where S::Scale: IsUnset,

Optional (Some / Option setters). Scale component of the transform.