EdgeSpecifierBuilder

Struct EdgeSpecifierBuilder 

pub struct EdgeSpecifierBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> EdgeSpecifierBuilder<S>

pub fn build(self) -> EdgeSpecifier
where S: IsComplete,

Finish building and return the requested object

pub fn side_faces( self, value: Vec<Uuid>, ) -> EdgeSpecifierBuilder<SetSideFaces<S>>
where S::SideFaces: IsUnset,

Required.

Side face ids that uniquely identify the edge.

pub fn end_faces(self, value: Vec<Uuid>) -> EdgeSpecifierBuilder<SetEndFaces<S>>
where S::EndFaces: IsUnset,

Optional (Some / Option setters). Default: <Vec<Uuid> as Default>::default().

Optional end face ids for ambiguous edge matches.

pub fn maybe_end_faces( self, value: Option<Vec<Uuid>>, ) -> EdgeSpecifierBuilder<SetEndFaces<S>>
where S::EndFaces: IsUnset,

Optional (Some / Option setters). Default: <Vec<Uuid> as Default>::default().

Optional end face ids for ambiguous edge matches.

pub fn index(self, value: u32) -> EdgeSpecifierBuilder<SetIndex<S>>
where S::Index: IsUnset,

Optional (Some / Option setters). Optional index for disambiguation when multiple edges share the same faces. If not provided (None), all matching edges will be used. If provided (Some(n)), only the edge at index n will be used.

pub fn maybe_index( self, value: Option<u32>, ) -> EdgeSpecifierBuilder<SetIndex<S>>
where S::Index: IsUnset,

Optional (Some / Option setters). Optional index for disambiguation when multiple edges share the same faces. If not provided (None), all matching edges will be used. If provided (Some(n)), only the edge at index n will be used.