pub struct FractionOfEdge {
pub edge_id: Uuid,
pub lower_bound: f32,
pub upper_bound: f32,
}Expand description
An edge id and an upper and lower percentage bound of the edge.
Fields
edge_id: UuidThe id of the edge
lower_bound: f32A value between [0.0, 1.0] (default 0.0) that is a percentage along the edge. This bound will control how much of the edge is used during the blend. If lower_bound is larger than upper_bound, the edge is effectively “flipped”.
upper_bound: f32A value between [0.0, 1.0] (default 1.0) that is a percentage along the edge. This bound will control how much of the edge is used during the blend. If lower_bound is larger than upper_bound, the edge is effectively “flipped”.
Implementations
Sourceimpl FractionOfEdge
impl FractionOfEdge
Sourcepub fn builder() -> FractionOfEdgeBuilder
pub fn builder() -> FractionOfEdgeBuilder
Create an instance of FractionOfEdge using the builder syntax