pub struct RotationBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> RotationBuilder<S>
impl<S: State> RotationBuilder<S>
Sourcepub fn build(self) -> Rotationwhere
S: IsComplete,
pub fn build(self) -> Rotationwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn axis(self, value: Point3d<f64>) -> RotationBuilder<SetAxis<S>>where
S::Axis: IsUnset,
pub fn axis(self, value: Point3d<f64>) -> RotationBuilder<SetAxis<S>>where
S::Axis: IsUnset,
Required.
Rotation axis. Defaults to (0, 0, 1) (i.e. the Z axis).
Sourcepub fn angle(self, value: Angle) -> RotationBuilder<SetAngle<S>>where
S::Angle: IsUnset,
pub fn angle(self, value: Angle) -> RotationBuilder<SetAngle<S>>where
S::Angle: IsUnset,
Required.
Rotate this far about the rotation axis. Defaults to zero (i.e. no rotation).
Sourcepub fn origin(self, value: OriginType) -> RotationBuilder<SetOrigin<S>>where
S::Origin: IsUnset,
pub fn origin(self, value: OriginType) -> RotationBuilder<SetOrigin<S>>where
S::Origin: IsUnset,
Required.
Origin of the rotation. If one isn’t provided, the object will rotate about its own bounding box center.