TransformByBuilder

Struct TransformByBuilder 

pub struct TransformByBuilder<T, S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<T, S: State> TransformByBuilder<T, S>

pub fn build(self) -> TransformBy<T>
where S: IsComplete,

Finish building and return the requested object

pub fn property(self, value: T) -> TransformByBuilder<T, SetProperty<S>>
where S::Property: IsUnset,

Required.

The scale, or rotation, or translation.

pub fn set(self, value: bool) -> TransformByBuilder<T, SetSet<S>>
where S::Set: IsUnset,

Required.

If true, overwrite the previous value with this. If false, the previous value will be modified. E.g. when translating, set=true will set a new location, and set=false will translate the current location by the given X/Y/Z.

pub fn origin(self, value: OriginType) -> TransformByBuilder<T, SetOrigin<S>>
where S::Origin: IsUnset,

Optional (Some / Option setters). Default: <OriginType as Default>::default().

What to use as the origin for the transformation.

pub fn maybe_origin( self, value: Option<OriginType>, ) -> TransformByBuilder<T, SetOrigin<S>>
where S::Origin: IsUnset,

Optional (Some / Option setters). Default: <OriginType as Default>::default().

What to use as the origin for the transformation.