DefaultCameraCenterToSelectionBuilder

Struct DefaultCameraCenterToSelectionBuilder 

pub struct DefaultCameraCenterToSelectionBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> DefaultCameraCenterToSelectionBuilder<S>

pub fn build(self) -> DefaultCameraCenterToSelection
where S: IsComplete,

Finish building and return the requested object

pub fn camera_movement( self, value: CameraMovement, ) -> DefaultCameraCenterToSelectionBuilder<SetCameraMovement<S>>
where S::CameraMovement: IsUnset,

Optional (Some / Option setters). Default: <CameraMovement as Default>::default().

Dictates whether or not the camera position should be adjusted during this operation If no movement is requested, the camera will orbit around the new center from its current position

pub fn maybe_camera_movement( self, value: Option<CameraMovement>, ) -> DefaultCameraCenterToSelectionBuilder<SetCameraMovement<S>>
where S::CameraMovement: IsUnset,

Optional (Some / Option setters). Default: <CameraMovement as Default>::default().

Dictates whether or not the camera position should be adjusted during this operation If no movement is requested, the camera will orbit around the new center from its current position