DefaultCameraPerspectiveSettingsBuilder

Struct DefaultCameraPerspectiveSettingsBuilder 

pub struct DefaultCameraPerspectiveSettingsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> DefaultCameraPerspectiveSettingsBuilder<S>

pub fn build(self) -> DefaultCameraPerspectiveSettings
where S: IsComplete,

Finish building and return the requested object

pub fn vantage( self, value: Point3d, ) -> DefaultCameraPerspectiveSettingsBuilder<SetVantage<S>>
where S::Vantage: IsUnset,

Required.

Where the camera is positioned

pub fn center( self, value: Point3d, ) -> DefaultCameraPerspectiveSettingsBuilder<SetCenter<S>>
where S::Center: IsUnset,

Required.

What the camera is looking at. Center of the camera’s field of vision

pub fn up( self, value: Point3d, ) -> DefaultCameraPerspectiveSettingsBuilder<SetUp<S>>
where S::Up: IsUnset,

Required.

Which way is “up”, from the camera’s point of view.

pub fn fov_y( self, value: f32, ) -> DefaultCameraPerspectiveSettingsBuilder<SetFovY<S>>
where S::FovY: IsUnset,

Optional (Some / Option setters). The field of view angle in the y direction, in degrees.

pub fn maybe_fov_y( self, value: Option<f32>, ) -> DefaultCameraPerspectiveSettingsBuilder<SetFovY<S>>
where S::FovY: IsUnset,

Optional (Some / Option setters). The field of view angle in the y direction, in degrees.

pub fn z_near( self, value: f32, ) -> DefaultCameraPerspectiveSettingsBuilder<SetZNear<S>>
where S::ZNear: IsUnset,

Optional (Some / Option setters). The distance to the near clipping plane.

pub fn maybe_z_near( self, value: Option<f32>, ) -> DefaultCameraPerspectiveSettingsBuilder<SetZNear<S>>
where S::ZNear: IsUnset,

Optional (Some / Option setters). The distance to the near clipping plane.

pub fn z_far( self, value: f32, ) -> DefaultCameraPerspectiveSettingsBuilder<SetZFar<S>>
where S::ZFar: IsUnset,

Optional (Some / Option setters). The distance to the far clipping plane.

pub fn maybe_z_far( self, value: Option<f32>, ) -> DefaultCameraPerspectiveSettingsBuilder<SetZFar<S>>
where S::ZFar: IsUnset,

Optional (Some / Option setters). The distance to the far clipping plane.

pub fn sequence( self, value: u32, ) -> DefaultCameraPerspectiveSettingsBuilder<SetSequence<S>>
where S::Sequence: IsUnset,

Optional (Some / Option setters). Logical timestamp. The client should increment this with every event in the current mouse drag. That way, if the events are being sent over an unordered channel, the API can ignore the older events.

pub fn maybe_sequence( self, value: Option<u32>, ) -> DefaultCameraPerspectiveSettingsBuilder<SetSequence<S>>
where S::Sequence: IsUnset,

Optional (Some / Option setters). Logical timestamp. The client should increment this with every event in the current mouse drag. That way, if the events are being sent over an unordered channel, the API can ignore the older events.