EntityLinearPatternTransformBuilder

Struct EntityLinearPatternTransformBuilder 

pub struct EntityLinearPatternTransformBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> EntityLinearPatternTransformBuilder<S>

pub fn build(self) -> EntityLinearPatternTransform
where S: IsComplete,

Finish building and return the requested object

pub fn entity_id( self, value: Uuid, ) -> EntityLinearPatternTransformBuilder<SetEntityId<S>>
where S::EntityId: IsUnset,

Required.

ID of the entity being copied.

pub fn transform( self, value: Vec<Transform>, ) -> EntityLinearPatternTransformBuilder<SetTransform<S>>
where S::Transform: IsUnset,

Optional (Some / Option setters). Default: <Vec<crate::shared::Transform> as Default>::default().

How to transform each repeated solid. The 0th transform will create the first copy of the entity. The total number of (optional) repetitions equals the size of this list.

pub fn maybe_transform( self, value: Option<Vec<Transform>>, ) -> EntityLinearPatternTransformBuilder<SetTransform<S>>
where S::Transform: IsUnset,

Optional (Some / Option setters). Default: <Vec<crate::shared::Transform> as Default>::default().

How to transform each repeated solid. The 0th transform will create the first copy of the entity. The total number of (optional) repetitions equals the size of this list.

pub fn transforms( self, value: Vec<Vec<Transform>>, ) -> EntityLinearPatternTransformBuilder<SetTransforms<S>>
where S::Transforms: IsUnset,

Optional (Some / Option setters). Default: <Vec<Vec<crate::shared::Transform>> as Default>::default().

Alternatively, you could set this key instead. If you want to use multiple transforms per item. If this is non-empty then the transform key must be empty, and vice-versa.

pub fn maybe_transforms( self, value: Option<Vec<Vec<Transform>>>, ) -> EntityLinearPatternTransformBuilder<SetTransforms<S>>
where S::Transforms: IsUnset,

Optional (Some / Option setters). Default: <Vec<Vec<crate::shared::Transform>> as Default>::default().

Alternatively, you could set this key instead. If you want to use multiple transforms per item. If this is non-empty then the transform key must be empty, and vice-versa.