pub struct Extrude {
pub target: ModelingCmdId,
pub distance: LengthUnit,
pub draft_angle: Option<Angle>,
pub faces: Option<ExtrudedFaceInfo>,
pub opposite: Opposite<LengthUnit>,
pub extrude_method: ExtrudeMethod,
pub merge_coplanar_faces: Option<bool>,
pub body_type: BodyType,
}Expand description
Command for extruding a solid 2d.
Fields
target: ModelingCmdIdWhich sketch to extrude. Must be a closed 2D solid.
distance: LengthUnitHow far off the plane to extrude
draft_angle: Option<Angle>What draft angle should be used in this extrusion? Negative values indicate an outward draft, while positive values indicate an inward draft
faces: Option<ExtrudedFaceInfo>Which IDs should the new faces have? If this isn’t given, the engine will generate IDs.
opposite: Opposite<LengthUnit>Should the extrusion also extrude in the opposite direction? If so, this specifies its distance.
extrude_method: ExtrudeMethodShould the extrusion create a new object or be part of the existing object.
merge_coplanar_faces: Option<bool>Only used if the extrusion is created from a face and extrude_method = Merge If true, coplanar faces will be merged and seams will be hidden. Otherwise, seams between the extrusion and original body will be shown.
body_type: BodyTypeShould this extrude create a solid body or a surface?
Implementations