pub struct ProjectPointsToPlaneBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> ProjectPointsToPlaneBuilder<S>
impl<S: State> ProjectPointsToPlaneBuilder<S>
Sourcepub fn build(self) -> ProjectPointsToPlanewhere
S: IsComplete,
pub fn build(self) -> ProjectPointsToPlanewhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn plane_id(self, value: Uuid) -> ProjectPointsToPlaneBuilder<SetPlaneId<S>>where
S::PlaneId: IsUnset,
pub fn plane_id(self, value: Uuid) -> ProjectPointsToPlaneBuilder<SetPlaneId<S>>where
S::PlaneId: IsUnset,
Required.
The id of the plane used for the projection.
Sourcepub fn points(
self,
value: Vec<Point3d<f64>>,
) -> ProjectPointsToPlaneBuilder<SetPoints<S>>where
S::Points: IsUnset,
pub fn points(
self,
value: Vec<Point3d<f64>>,
) -> ProjectPointsToPlaneBuilder<SetPoints<S>>where
S::Points: IsUnset,
Required.
The list of points that will be projected.
Sourcepub fn use_plane_coords(
self,
value: bool,
) -> ProjectPointsToPlaneBuilder<SetUsePlaneCoords<S>>where
S::UsePlaneCoords: IsUnset,
pub fn use_plane_coords(
self,
value: bool,
) -> ProjectPointsToPlaneBuilder<SetUsePlaneCoords<S>>where
S::UsePlaneCoords: IsUnset,
Required.
If true: the projected points are returned in the plane_id’s coordinate sysetm. else: the projected points are returned in the world coordinate system.