pub struct RevolveAboutEdge {
pub target: ModelingCmdId,
pub edge_id: Option<Uuid>,
pub edge_reference: Option<EdgeSpecifier>,
pub angle: Angle,
pub tolerance: LengthUnit,
pub opposite: Opposite<Angle>,
pub body_type: BodyType,
}Expand description
Command for revolving a solid 2d about a brep edge
Fields
target: ModelingCmdIdWhich sketch to revolve. Must be a closed 2D solid.
edge_id: Option<Uuid>The edge to use as the axis of revolution, must be linear and lie in the plane of the solid
edge_reference: Option<EdgeSpecifier>Edge reference to use as the axis of revolution (new API).
If both edge_id and edge_reference are provided, edge_reference takes precedence.
angle: AngleThe signed angle of revolution (in degrees, must be <= 360 in either direction)
tolerance: LengthUnitThe maximum acceptable surface gap computed between the revolution surface joints. Must be positive (i.e. greater than zero).
opposite: Opposite<Angle>Should the revolution also revolve in the opposite direction along the given axis? If so, this specifies its angle.
body_type: BodyTypeShould this extrude create a solid body or a surface?
Implementations
Sourceimpl RevolveAboutEdge
impl RevolveAboutEdge
Sourcepub fn builder() -> RevolveAboutEdgeBuilder
pub fn builder() -> RevolveAboutEdgeBuilder
Create an instance of RevolveAboutEdge using the builder syntax