RevolveBuilder

Struct RevolveBuilder 

pub struct RevolveBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> RevolveBuilder<S>

pub fn build(self) -> Revolve
where S: IsComplete,

Finish building and return the requested object

pub fn target(self, value: ModelingCmdId) -> RevolveBuilder<SetTarget<S>>
where S::Target: IsUnset,

Required.

Which sketch to revolve. Must be a closed 2D solid.

pub fn origin(self, value: Point3d<LengthUnit>) -> RevolveBuilder<SetOrigin<S>>
where S::Origin: IsUnset,

Required.

The origin of the extrusion axis

pub fn axis(self, value: Point3d<f64>) -> RevolveBuilder<SetAxis<S>>
where S::Axis: IsUnset,

Required.

The axis of the extrusion (taken from the origin)

pub fn axis_is_2d(self, value: bool) -> RevolveBuilder<SetAxisIs2d<S>>
where S::AxisIs2d: IsUnset,

Required.

If true, the axis is interpreted within the 2D space of the solid 2D’s plane

pub fn angle(self, value: Angle) -> RevolveBuilder<SetAngle<S>>
where S::Angle: IsUnset,

Required.

The signed angle of revolution (in degrees, must be <= 360 in either direction)

pub fn tolerance(self, value: LengthUnit) -> RevolveBuilder<SetTolerance<S>>
where S::Tolerance: IsUnset,

Required.

The maximum acceptable surface gap computed between the revolution surface joints. Must be positive (i.e. greater than zero).

pub fn opposite(self, value: Opposite<Angle>) -> RevolveBuilder<SetOpposite<S>>
where S::Opposite: IsUnset,

Optional (Some / Option setters). Default: <Opposite<Angle> as Default>::default().

Should the revolution also revolve in the opposite direction along the given axis? If so, this specifies its angle.

pub fn maybe_opposite( self, value: Option<Opposite<Angle>>, ) -> RevolveBuilder<SetOpposite<S>>
where S::Opposite: IsUnset,

Optional (Some / Option setters). Default: <Opposite<Angle> as Default>::default().

Should the revolution also revolve in the opposite direction along the given axis? If so, this specifies its angle.

pub fn body_type(self, value: BodyType) -> RevolveBuilder<SetBodyType<S>>
where S::BodyType: IsUnset,

Optional (Some / Option setters). Default: <BodyType as Default>::default().

Should this extrude create a solid body or a surface?

pub fn maybe_body_type( self, value: Option<BodyType>, ) -> RevolveBuilder<SetBodyType<S>>
where S::BodyType: IsUnset,

Optional (Some / Option setters). Default: <BodyType as Default>::default().

Should this extrude create a solid body or a surface?