pub struct SceneGetEntityIds {
pub filter: Vec<EntityType>,
pub skip: u32,
pub take: u32,
}Expand description
Get the ids of a given entity type.
Fields
filter: Vec<EntityType>The entity types to be queried.
skip: u32Skip the first n returned ids. If multiple filters are provided, this skip will apply to each filter individually.
take: u32Take n ids after any ids skipped. This value must be greater than zero and not
exceed 1000. If multiple filters are provided, this take will apply to each filter
individually. If there are fewer than take items of the provided filter type then the
returned list’s length will be the smaller value.
Implementations
Sourceimpl SceneGetEntityIds
impl SceneGetEntityIds
Sourcepub fn builder() -> SceneGetEntityIdsBuilder
pub fn builder() -> SceneGetEntityIdsBuilder
Create an instance of SceneGetEntityIds using the builder syntax