pub struct SetGridReferencePlaneBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> SetGridReferencePlaneBuilder<S>
impl<S: State> SetGridReferencePlaneBuilder<S>
Sourcepub fn build(self) -> SetGridReferencePlanewhere
S: IsComplete,
pub fn build(self) -> SetGridReferencePlanewhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn grid_id(self, value: Uuid) -> SetGridReferencePlaneBuilder<SetGridId<S>>where
S::GridId: IsUnset,
pub fn grid_id(self, value: Uuid) -> SetGridReferencePlaneBuilder<SetGridId<S>>where
S::GridId: IsUnset,
Required.
The grid to be moved.
Sourcepub fn reference_id(
self,
value: Uuid,
) -> SetGridReferencePlaneBuilder<SetReferenceId<S>>where
S::ReferenceId: IsUnset,
pub fn reference_id(
self,
value: Uuid,
) -> SetGridReferencePlaneBuilder<SetReferenceId<S>>where
S::ReferenceId: IsUnset,
Required.
The plane or face that the grid will be aligned to. If a face, it must be planar to succeed.