pub struct Solid3dCutEdgeReferences {
pub object_id: Uuid,
pub edges_references: Vec<EdgeSpecifier>,
pub cut_type: CutTypeV2,
pub tolerance: LengthUnit,
pub strategy: CutStrategy,
pub extra_face_ids: Vec<Uuid>,
pub use_legacy: bool,
}Expand description
Cut the list of edge references with the given cut parameters
Fields
object_id: UuidWhich object is being cut.
edges_references: Vec<EdgeSpecifier>A struct containing the information required to reference an edge.
cut_type: CutTypeV2The cut type and information required to perform the cut.
tolerance: LengthUnitThe maximum acceptable surface gap computed between the cut surfaces. Must be positive (i.e. greater than zero).
strategy: CutStrategyWhich cutting algorithm to use.
extra_face_ids: Vec<Uuid>What IDs should the resulting faces have?
If you’ve only passed one edge ID, its ID will
be the command ID used to send this command, and this
field should be empty.
If you’ve passed n IDs (to cut n edges), then
this should be length n-1, and the first edge will use
the command ID used to send this command.
use_legacy: boolIf true, use the legacy CSG algorithm.
Implementations
Sourceimpl Solid3dCutEdgeReferences
impl Solid3dCutEdgeReferences
Sourcepub fn builder() -> Solid3dCutEdgeReferencesBuilder
pub fn builder() -> Solid3dCutEdgeReferencesBuilder
Create an instance of Solid3dCutEdgeReferences using the builder syntax