Solid3dFilletEdgeBuilder

Struct Solid3dFilletEdgeBuilder 

pub struct Solid3dFilletEdgeBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> Solid3dFilletEdgeBuilder<S>

pub fn build(self) -> Solid3dFilletEdge
where S: IsComplete,

Finish building and return the requested object

pub fn object_id(self, value: Uuid) -> Solid3dFilletEdgeBuilder<SetObjectId<S>>
where S::ObjectId: IsUnset,

Required.

Which object is being filletted.

pub fn edge_id(self, value: Uuid) -> Solid3dFilletEdgeBuilder<SetEdgeId<S>>
where S::EdgeId: IsUnset,

Optional (Some / Option setters). Which edge you want to fillet.

pub fn maybe_edge_id( self, value: Option<Uuid>, ) -> Solid3dFilletEdgeBuilder<SetEdgeId<S>>
where S::EdgeId: IsUnset,

Optional (Some / Option setters). Which edge you want to fillet.

pub fn edge_ids( self, value: Vec<Uuid>, ) -> Solid3dFilletEdgeBuilder<SetEdgeIds<S>>
where S::EdgeIds: IsUnset,

Optional (Some / Option setters). Default: <Vec<Uuid> as Default>::default().

Which edges you want to fillet.

pub fn maybe_edge_ids( self, value: Option<Vec<Uuid>>, ) -> Solid3dFilletEdgeBuilder<SetEdgeIds<S>>
where S::EdgeIds: IsUnset,

Optional (Some / Option setters). Default: <Vec<Uuid> as Default>::default().

Which edges you want to fillet.

pub fn radius(self, value: LengthUnit) -> Solid3dFilletEdgeBuilder<SetRadius<S>>
where S::Radius: IsUnset,

Required.

The radius of the fillet. Measured in length (using the same units that the current sketch uses). Must be positive (i.e. greater than zero).

pub fn tolerance( self, value: LengthUnit, ) -> Solid3dFilletEdgeBuilder<SetTolerance<S>>
where S::Tolerance: IsUnset,

Required.

The maximum acceptable surface gap computed between the filleted surfaces. Must be positive (i.e. greater than zero).

pub fn cut_type(self, value: CutType) -> Solid3dFilletEdgeBuilder<SetCutType<S>>
where S::CutType: IsUnset,

Optional (Some / Option setters). Default: <CutType as Default>::default().

How to apply the cut.

pub fn maybe_cut_type( self, value: Option<CutType>, ) -> Solid3dFilletEdgeBuilder<SetCutType<S>>
where S::CutType: IsUnset,

Optional (Some / Option setters). Default: <CutType as Default>::default().

How to apply the cut.

pub fn strategy( self, value: CutStrategy, ) -> Solid3dFilletEdgeBuilder<SetStrategy<S>>
where S::Strategy: IsUnset,

Optional (Some / Option setters). Default: <CutStrategy as Default>::default().

Which cutting algorithm to use.

pub fn maybe_strategy( self, value: Option<CutStrategy>, ) -> Solid3dFilletEdgeBuilder<SetStrategy<S>>
where S::Strategy: IsUnset,

Optional (Some / Option setters). Default: <CutStrategy as Default>::default().

Which cutting algorithm to use.

pub fn extra_face_ids( self, value: Vec<Uuid>, ) -> Solid3dFilletEdgeBuilder<SetExtraFaceIds<S>>
where S::ExtraFaceIds: IsUnset,

Optional (Some / Option setters). Default: <Vec<Uuid> as Default>::default().

What IDs should the resulting faces have? If you’ve only passed one edge ID, its ID will be the command ID used to send this command, and this field should be empty. If you’ve passed n IDs (to fillet n edges), then this should be length n-1, and the first edge will use the command ID used to send this command.

pub fn maybe_extra_face_ids( self, value: Option<Vec<Uuid>>, ) -> Solid3dFilletEdgeBuilder<SetExtraFaceIds<S>>
where S::ExtraFaceIds: IsUnset,

Optional (Some / Option setters). Default: <Vec<Uuid> as Default>::default().

What IDs should the resulting faces have? If you’ve only passed one edge ID, its ID will be the command ID used to send this command, and this field should be empty. If you’ve passed n IDs (to fillet n edges), then this should be length n-1, and the first edge will use the command ID used to send this command.

pub fn use_legacy( self, value: bool, ) -> Solid3dFilletEdgeBuilder<SetUseLegacy<S>>
where S::UseLegacy: IsUnset,

Optional (Some / Option setters). Default: false.

If true, use the legacy CSG algorithm.

pub fn maybe_use_legacy( self, value: Option<bool>, ) -> Solid3dFilletEdgeBuilder<SetUseLegacy<S>>
where S::UseLegacy: IsUnset,

Optional (Some / Option setters). Default: false.

If true, use the legacy CSG algorithm.