pub struct Solid3dMultiJoinBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> Solid3dMultiJoinBuilder<S>
impl<S: State> Solid3dMultiJoinBuilder<S>
Sourcepub fn build(self) -> Solid3dMultiJoinwhere
S: IsComplete,
pub fn build(self) -> Solid3dMultiJoinwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn object_ids(
self,
value: Vec<Uuid>,
) -> Solid3dMultiJoinBuilder<SetObjectIds<S>>where
S::ObjectIds: IsUnset,
pub fn object_ids(
self,
value: Vec<Uuid>,
) -> Solid3dMultiJoinBuilder<SetObjectIds<S>>where
S::ObjectIds: IsUnset,
Required.
Which bodies are being joined.
Sourcepub fn tolerance(
self,
value: LengthUnit,
) -> Solid3dMultiJoinBuilder<SetTolerance<S>>where
S::Tolerance: IsUnset,
pub fn tolerance(
self,
value: LengthUnit,
) -> Solid3dMultiJoinBuilder<SetTolerance<S>>where
S::Tolerance: IsUnset,
Required.
The maximum acceptable surface gap computed between the joints. Must be positive (i.e. greater than zero).