Sweep

Struct Sweep 

pub struct Sweep {
    pub target: ModelingCmdId,
    pub trajectory: ModelingCmdId,
    pub sectional: bool,
    pub tolerance: LengthUnit,
    pub body_type: BodyType,
    pub relative_to: Option<RelativeTo>,
    pub version: Option<u8>,
    pub translate_profile_to_path: Option<bool>,
    pub orient_profile_perpendicular: Option<bool>,
}
Extrude the object along a path.

Fields

target: ModelingCmdId

Which sketch to sweep. Must be a closed 2D solid.

trajectory: ModelingCmdId

Path along which to sweep.

sectional: bool

If true, the sweep will be broken up into sub-sweeps (extrusions, revolves, sweeps) based on the trajectory path components.

tolerance: LengthUnit

The maximum acceptable surface gap computed between the revolution surface joints. Must be positive (i.e. greater than zero).

body_type: BodyType

Should this sweep create a solid body or a surface?

relative_to: Option<RelativeTo>

What is this sweep relative to? Deprecated; please use translate_profile_to_path and orient_profile_perpendicular instead.

version: Option<u8>

What version of the sweeping algorithm to use. If None, or zero, the engine’s default algorithm will be used

translate_profile_to_path: Option<bool>

If true, the profile being swept will be moved to the path being swept along, before the sweep starts. If false, the profile stays where it is, and the sweep starts from there. Defaults to false.

orient_profile_perpendicular: Option<bool>

If true, before the sweep starts, the profile will be re-oriented so that it is perpendicular to the path being swept along. If false, the profile is left in its current orientation. Defaults to false.

Implementations

Source

impl Sweep

pub fn builder() -> SweepBuilder

Create an instance of Sweep using the builder syntax