pub struct ViewIsometricBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> ViewIsometricBuilder<S>
impl<S: State> ViewIsometricBuilder<S>
Sourcepub fn build(self) -> ViewIsometricwhere
S: IsComplete,
pub fn build(self) -> ViewIsometricwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn padding(self, value: f32) -> ViewIsometricBuilder<SetPadding<S>>where
S::Padding: IsUnset,
pub fn padding(self, value: f32) -> ViewIsometricBuilder<SetPadding<S>>where
S::Padding: IsUnset,
Optional (Some / Option setters).
Default: 0.0.
How much to pad the view frame by, as a fraction of the object(s) bounding box size. Negative padding will crop the view of the object proportionally. e.g. padding = 0.2 means the view will span 120% of the object(s) bounding box, and padding = -0.2 means the view will span 80% of the object(s) bounding box.
Sourcepub fn maybe_padding(
self,
value: Option<f32>,
) -> ViewIsometricBuilder<SetPadding<S>>where
S::Padding: IsUnset,
pub fn maybe_padding(
self,
value: Option<f32>,
) -> ViewIsometricBuilder<SetPadding<S>>where
S::Padding: IsUnset,
Optional (Some / Option setters).
Default: 0.0.
How much to pad the view frame by, as a fraction of the object(s) bounding box size. Negative padding will crop the view of the object proportionally. e.g. padding = 0.2 means the view will span 120% of the object(s) bounding box, and padding = -0.2 means the view will span 80% of the object(s) bounding box.