pub struct RawFile {
pub name: String,
pub contents: Vec<u8>,
}Expand description
A raw file with unencoded contents to be passed over binary websockets. When raw files come back for exports it is sent as binary/bson, not text/json.
Fields
name: StringThe name of the file.
contents: Vec<u8>The contents of the file.