pub struct BooleanIntersection {
pub extra_solid_ids: Vec<Uuid>,
pub any_intersections: bool,
}Expand description
The response from the ‘BooleanIntersection’.
Fields
extra_solid_ids: Vec<Uuid>If the operation produced just one solid, then its ID will be the ID of the modeling command request. But if any extra solids are produced, then their IDs will be included here.
any_intersections: boolIf the operation involved any intersecting solids.