pub struct AnnotationBasicDimensionBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> AnnotationBasicDimensionBuilder<S>
impl<S: State> AnnotationBasicDimensionBuilder<S>
Sourcepub fn build(self) -> AnnotationBasicDimensionwhere
S: IsComplete,
pub fn build(self) -> AnnotationBasicDimensionwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn from_entity_id(
self,
value: Uuid,
) -> AnnotationBasicDimensionBuilder<SetFromEntityId<S>>where
S::FromEntityId: IsUnset,
pub fn from_entity_id(
self,
value: Uuid,
) -> AnnotationBasicDimensionBuilder<SetFromEntityId<S>>where
S::FromEntityId: IsUnset,
Required.
Entity to measure the dimension from
Sourcepub fn from_entity_pos(
self,
value: Point2d<f64>,
) -> AnnotationBasicDimensionBuilder<SetFromEntityPos<S>>where
S::FromEntityPos: IsUnset,
pub fn from_entity_pos(
self,
value: Point2d<f64>,
) -> AnnotationBasicDimensionBuilder<SetFromEntityPos<S>>where
S::FromEntityPos: IsUnset,
Required.
Normalized position within the entity to position the dimension from
Sourcepub fn to_entity_id(
self,
value: Uuid,
) -> AnnotationBasicDimensionBuilder<SetToEntityId<S>>where
S::ToEntityId: IsUnset,
pub fn to_entity_id(
self,
value: Uuid,
) -> AnnotationBasicDimensionBuilder<SetToEntityId<S>>where
S::ToEntityId: IsUnset,
Required.
Entity to measure the dimension to
Sourcepub fn to_entity_pos(
self,
value: Point2d<f64>,
) -> AnnotationBasicDimensionBuilder<SetToEntityPos<S>>where
S::ToEntityPos: IsUnset,
pub fn to_entity_pos(
self,
value: Point2d<f64>,
) -> AnnotationBasicDimensionBuilder<SetToEntityPos<S>>where
S::ToEntityPos: IsUnset,
Required.
Normalized position within the entity to position the dimension to
Sourcepub fn dimension(
self,
value: AnnotationMbdBasicDimension,
) -> AnnotationBasicDimensionBuilder<SetDimension<S>>where
S::Dimension: IsUnset,
pub fn dimension(
self,
value: AnnotationMbdBasicDimension,
) -> AnnotationBasicDimensionBuilder<SetDimension<S>>where
S::Dimension: IsUnset,
Required.
Basic dimension parameters (symbol and tolerance)
Sourcepub fn plane_id(
self,
value: Uuid,
) -> AnnotationBasicDimensionBuilder<SetPlaneId<S>>where
S::PlaneId: IsUnset,
pub fn plane_id(
self,
value: Uuid,
) -> AnnotationBasicDimensionBuilder<SetPlaneId<S>>where
S::PlaneId: IsUnset,
Required.
Orientation plane. The annotation will lie in this plane which is positioned about the leader position as its origin.
Sourcepub fn offset(
self,
value: Point2d<f64>,
) -> AnnotationBasicDimensionBuilder<SetOffset<S>>where
S::Offset: IsUnset,
pub fn offset(
self,
value: Point2d<f64>,
) -> AnnotationBasicDimensionBuilder<SetOffset<S>>where
S::Offset: IsUnset,
Required.
2D Position offset of the annotation within the plane.
Sourcepub fn precision(
self,
value: u32,
) -> AnnotationBasicDimensionBuilder<SetPrecision<S>>where
S::Precision: IsUnset,
pub fn precision(
self,
value: u32,
) -> AnnotationBasicDimensionBuilder<SetPrecision<S>>where
S::Precision: IsUnset,
Required.
Number of decimal places to use when displaying tolerance and dimension values
Sourcepub fn font_scale(
self,
value: f32,
) -> AnnotationBasicDimensionBuilder<SetFontScale<S>>where
S::FontScale: IsUnset,
pub fn font_scale(
self,
value: f32,
) -> AnnotationBasicDimensionBuilder<SetFontScale<S>>where
S::FontScale: IsUnset,
Required.
The scale of the font label in 3D space
Sourcepub fn font_point_size(
self,
value: u32,
) -> AnnotationBasicDimensionBuilder<SetFontPointSize<S>>where
S::FontPointSize: IsUnset,
pub fn font_point_size(
self,
value: u32,
) -> AnnotationBasicDimensionBuilder<SetFontPointSize<S>>where
S::FontPointSize: IsUnset,
Required.
The point size of the fonts used to generate the annotation label. Very large values can negatively affect performance.
Sourcepub fn arrow_scale(
self,
value: f32,
) -> AnnotationBasicDimensionBuilder<SetArrowScale<S>>where
S::ArrowScale: IsUnset,
pub fn arrow_scale(
self,
value: f32,
) -> AnnotationBasicDimensionBuilder<SetArrowScale<S>>where
S::ArrowScale: IsUnset,
Required.
The scale of the dimension arrows. Defaults to 1.