pub struct AnnotationFeatureControlBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> AnnotationFeatureControlBuilder<S>
impl<S: State> AnnotationFeatureControlBuilder<S>
Sourcepub fn build(self) -> AnnotationFeatureControlwhere
S: IsComplete,
pub fn build(self) -> AnnotationFeatureControlwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn entity_id(
self,
value: Uuid,
) -> AnnotationFeatureControlBuilder<SetEntityId<S>>where
S::EntityId: IsUnset,
pub fn entity_id(
self,
value: Uuid,
) -> AnnotationFeatureControlBuilder<SetEntityId<S>>where
S::EntityId: IsUnset,
Required.
Entity to place the annotation leader from
Sourcepub fn entity_pos(
self,
value: Point2d<f64>,
) -> AnnotationFeatureControlBuilder<SetEntityPos<S>>where
S::EntityPos: IsUnset,
pub fn entity_pos(
self,
value: Point2d<f64>,
) -> AnnotationFeatureControlBuilder<SetEntityPos<S>>where
S::EntityPos: IsUnset,
Required.
Normalized position within the entity to position the annotation leader from
Sourcepub fn leader_type(
self,
value: AnnotationLineEnd,
) -> AnnotationFeatureControlBuilder<SetLeaderType<S>>where
S::LeaderType: IsUnset,
pub fn leader_type(
self,
value: AnnotationLineEnd,
) -> AnnotationFeatureControlBuilder<SetLeaderType<S>>where
S::LeaderType: IsUnset,
Required.
Type of leader to use
Sourcepub fn dimension(
self,
value: AnnotationMbdBasicDimension,
) -> AnnotationFeatureControlBuilder<SetDimension<S>>where
S::Dimension: IsUnset,
pub fn dimension(
self,
value: AnnotationMbdBasicDimension,
) -> AnnotationFeatureControlBuilder<SetDimension<S>>where
S::Dimension: IsUnset,
Sourcepub fn maybe_dimension(
self,
value: Option<AnnotationMbdBasicDimension>,
) -> AnnotationFeatureControlBuilder<SetDimension<S>>where
S::Dimension: IsUnset,
pub fn maybe_dimension(
self,
value: Option<AnnotationMbdBasicDimension>,
) -> AnnotationFeatureControlBuilder<SetDimension<S>>where
S::Dimension: IsUnset,
Sourcepub fn control_frame(
self,
value: AnnotationMbdControlFrame,
) -> AnnotationFeatureControlBuilder<SetControlFrame<S>>where
S::ControlFrame: IsUnset,
pub fn control_frame(
self,
value: AnnotationMbdControlFrame,
) -> AnnotationFeatureControlBuilder<SetControlFrame<S>>where
S::ControlFrame: IsUnset,
Sourcepub fn maybe_control_frame(
self,
value: Option<AnnotationMbdControlFrame>,
) -> AnnotationFeatureControlBuilder<SetControlFrame<S>>where
S::ControlFrame: IsUnset,
pub fn maybe_control_frame(
self,
value: Option<AnnotationMbdControlFrame>,
) -> AnnotationFeatureControlBuilder<SetControlFrame<S>>where
S::ControlFrame: IsUnset,
Sourcepub fn defined_datum(
self,
value: char,
) -> AnnotationFeatureControlBuilder<SetDefinedDatum<S>>where
S::DefinedDatum: IsUnset,
pub fn defined_datum(
self,
value: char,
) -> AnnotationFeatureControlBuilder<SetDefinedDatum<S>>where
S::DefinedDatum: IsUnset,
Sourcepub fn maybe_defined_datum(
self,
value: Option<char>,
) -> AnnotationFeatureControlBuilder<SetDefinedDatum<S>>where
S::DefinedDatum: IsUnset,
pub fn maybe_defined_datum(
self,
value: Option<char>,
) -> AnnotationFeatureControlBuilder<SetDefinedDatum<S>>where
S::DefinedDatum: IsUnset,
Sourcepub fn prefix(
self,
value: String,
) -> AnnotationFeatureControlBuilder<SetPrefix<S>>where
S::Prefix: IsUnset,
pub fn prefix(
self,
value: String,
) -> AnnotationFeatureControlBuilder<SetPrefix<S>>where
S::Prefix: IsUnset,
Sourcepub fn maybe_prefix(
self,
value: Option<String>,
) -> AnnotationFeatureControlBuilder<SetPrefix<S>>where
S::Prefix: IsUnset,
pub fn maybe_prefix(
self,
value: Option<String>,
) -> AnnotationFeatureControlBuilder<SetPrefix<S>>where
S::Prefix: IsUnset,
Sourcepub fn suffix(
self,
value: String,
) -> AnnotationFeatureControlBuilder<SetSuffix<S>>where
S::Suffix: IsUnset,
pub fn suffix(
self,
value: String,
) -> AnnotationFeatureControlBuilder<SetSuffix<S>>where
S::Suffix: IsUnset,
Sourcepub fn maybe_suffix(
self,
value: Option<String>,
) -> AnnotationFeatureControlBuilder<SetSuffix<S>>where
S::Suffix: IsUnset,
pub fn maybe_suffix(
self,
value: Option<String>,
) -> AnnotationFeatureControlBuilder<SetSuffix<S>>where
S::Suffix: IsUnset,
Sourcepub fn plane_id(
self,
value: Uuid,
) -> AnnotationFeatureControlBuilder<SetPlaneId<S>>where
S::PlaneId: IsUnset,
pub fn plane_id(
self,
value: Uuid,
) -> AnnotationFeatureControlBuilder<SetPlaneId<S>>where
S::PlaneId: IsUnset,
Required.
Orientation plane. The annotation will lie in this plane which is positioned about the leader position as its origin.
Sourcepub fn offset(
self,
value: Point2d<f64>,
) -> AnnotationFeatureControlBuilder<SetOffset<S>>where
S::Offset: IsUnset,
pub fn offset(
self,
value: Point2d<f64>,
) -> AnnotationFeatureControlBuilder<SetOffset<S>>where
S::Offset: IsUnset,
Required.
2D Position offset of the annotation within the plane.
Sourcepub fn precision(
self,
value: u32,
) -> AnnotationFeatureControlBuilder<SetPrecision<S>>where
S::Precision: IsUnset,
pub fn precision(
self,
value: u32,
) -> AnnotationFeatureControlBuilder<SetPrecision<S>>where
S::Precision: IsUnset,
Required.
Number of decimal places to use when displaying tolerance and dimension values
Sourcepub fn font_scale(
self,
value: f32,
) -> AnnotationFeatureControlBuilder<SetFontScale<S>>where
S::FontScale: IsUnset,
pub fn font_scale(
self,
value: f32,
) -> AnnotationFeatureControlBuilder<SetFontScale<S>>where
S::FontScale: IsUnset,
Required.
The scale of the font label in 3D space
Sourcepub fn font_point_size(
self,
value: u32,
) -> AnnotationFeatureControlBuilder<SetFontPointSize<S>>where
S::FontPointSize: IsUnset,
pub fn font_point_size(
self,
value: u32,
) -> AnnotationFeatureControlBuilder<SetFontPointSize<S>>where
S::FontPointSize: IsUnset,
Required.
The point size of the fonts used to generate the annotation label. Very large values can negatively affect performance.
Sourcepub fn leader_scale(
self,
value: f32,
) -> AnnotationFeatureControlBuilder<SetLeaderScale<S>>where
S::LeaderScale: IsUnset,
pub fn leader_scale(
self,
value: f32,
) -> AnnotationFeatureControlBuilder<SetLeaderScale<S>>where
S::LeaderScale: IsUnset,
Required.
The scale of the leader (dot or arrow). Defaults to 1.