pub struct AnnotationFeatureTagBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> AnnotationFeatureTagBuilder<S>
impl<S: State> AnnotationFeatureTagBuilder<S>
Sourcepub fn build(self) -> AnnotationFeatureTagwhere
S: IsComplete,
pub fn build(self) -> AnnotationFeatureTagwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn entity_id(
self,
value: Uuid,
) -> AnnotationFeatureTagBuilder<SetEntityId<S>>where
S::EntityId: IsUnset,
pub fn entity_id(
self,
value: Uuid,
) -> AnnotationFeatureTagBuilder<SetEntityId<S>>where
S::EntityId: IsUnset,
Required.
Entity to place the annotation leader from
Sourcepub fn entity_pos(
self,
value: Point2d<f64>,
) -> AnnotationFeatureTagBuilder<SetEntityPos<S>>where
S::EntityPos: IsUnset,
pub fn entity_pos(
self,
value: Point2d<f64>,
) -> AnnotationFeatureTagBuilder<SetEntityPos<S>>where
S::EntityPos: IsUnset,
Required.
Normalized position within the entity to position the annotation leader from
Sourcepub fn leader_type(
self,
value: AnnotationLineEnd,
) -> AnnotationFeatureTagBuilder<SetLeaderType<S>>where
S::LeaderType: IsUnset,
pub fn leader_type(
self,
value: AnnotationLineEnd,
) -> AnnotationFeatureTagBuilder<SetLeaderType<S>>where
S::LeaderType: IsUnset,
Required.
Type of leader to use
Sourcepub fn key(self, value: String) -> AnnotationFeatureTagBuilder<SetKey<S>>where
S::Key: IsUnset,
pub fn key(self, value: String) -> AnnotationFeatureTagBuilder<SetKey<S>>where
S::Key: IsUnset,
Required.
Tag key
Sourcepub fn value(self, value: String) -> AnnotationFeatureTagBuilder<SetValue<S>>where
S::Value: IsUnset,
pub fn value(self, value: String) -> AnnotationFeatureTagBuilder<SetValue<S>>where
S::Value: IsUnset,
Required.
Tag value
Sourcepub fn show_key(self, value: bool) -> AnnotationFeatureTagBuilder<SetShowKey<S>>where
S::ShowKey: IsUnset,
pub fn show_key(self, value: bool) -> AnnotationFeatureTagBuilder<SetShowKey<S>>where
S::ShowKey: IsUnset,
Required.
Whether or not to display the key on the annotation label
Sourcepub fn plane_id(self, value: Uuid) -> AnnotationFeatureTagBuilder<SetPlaneId<S>>where
S::PlaneId: IsUnset,
pub fn plane_id(self, value: Uuid) -> AnnotationFeatureTagBuilder<SetPlaneId<S>>where
S::PlaneId: IsUnset,
Required.
Orientation plane. The annotation will lie in this plane which is positioned about the leader position as its origin.
Sourcepub fn offset(
self,
value: Point2d<f64>,
) -> AnnotationFeatureTagBuilder<SetOffset<S>>where
S::Offset: IsUnset,
pub fn offset(
self,
value: Point2d<f64>,
) -> AnnotationFeatureTagBuilder<SetOffset<S>>where
S::Offset: IsUnset,
Required.
2D Position offset of the annotation within the plane.
Sourcepub fn font_scale(
self,
value: f32,
) -> AnnotationFeatureTagBuilder<SetFontScale<S>>where
S::FontScale: IsUnset,
pub fn font_scale(
self,
value: f32,
) -> AnnotationFeatureTagBuilder<SetFontScale<S>>where
S::FontScale: IsUnset,
Required.
The scale of the font label in 3D space
Sourcepub fn font_point_size(
self,
value: u32,
) -> AnnotationFeatureTagBuilder<SetFontPointSize<S>>where
S::FontPointSize: IsUnset,
pub fn font_point_size(
self,
value: u32,
) -> AnnotationFeatureTagBuilder<SetFontPointSize<S>>where
S::FontPointSize: IsUnset,
Required.
The point size of the fonts used to generate the annotation label. Very large values can negatively affect performance.
Sourcepub fn leader_scale(
self,
value: f32,
) -> AnnotationFeatureTagBuilder<SetLeaderScale<S>>where
S::LeaderScale: IsUnset,
pub fn leader_scale(
self,
value: f32,
) -> AnnotationFeatureTagBuilder<SetLeaderScale<S>>where
S::LeaderScale: IsUnset,
Required.
The scale of the leader (dot or arrow). Defaults to 1.