pub struct Solid3dFilletEdgeBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> Solid3dFilletEdgeBuilder<S>
impl<S: State> Solid3dFilletEdgeBuilder<S>
Sourcepub fn build(self) -> Solid3dFilletEdgewhere
S: IsComplete,
pub fn build(self) -> Solid3dFilletEdgewhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn object_id(self, value: Uuid) -> Solid3dFilletEdgeBuilder<SetObjectId<S>>where
S::ObjectId: IsUnset,
pub fn object_id(self, value: Uuid) -> Solid3dFilletEdgeBuilder<SetObjectId<S>>where
S::ObjectId: IsUnset,
Required.
Which object is being filletted.
Sourcepub fn edge_id(self, value: Uuid) -> Solid3dFilletEdgeBuilder<SetEdgeId<S>>where
S::EdgeId: IsUnset,
pub fn edge_id(self, value: Uuid) -> Solid3dFilletEdgeBuilder<SetEdgeId<S>>where
S::EdgeId: IsUnset,
Sourcepub fn maybe_edge_id(
self,
value: Option<Uuid>,
) -> Solid3dFilletEdgeBuilder<SetEdgeId<S>>where
S::EdgeId: IsUnset,
pub fn maybe_edge_id(
self,
value: Option<Uuid>,
) -> Solid3dFilletEdgeBuilder<SetEdgeId<S>>where
S::EdgeId: IsUnset,
Sourcepub fn edge_ids(
self,
value: Vec<Uuid>,
) -> Solid3dFilletEdgeBuilder<SetEdgeIds<S>>where
S::EdgeIds: IsUnset,
pub fn edge_ids(
self,
value: Vec<Uuid>,
) -> Solid3dFilletEdgeBuilder<SetEdgeIds<S>>where
S::EdgeIds: IsUnset,
Sourcepub fn maybe_edge_ids(
self,
value: Option<Vec<Uuid>>,
) -> Solid3dFilletEdgeBuilder<SetEdgeIds<S>>where
S::EdgeIds: IsUnset,
pub fn maybe_edge_ids(
self,
value: Option<Vec<Uuid>>,
) -> Solid3dFilletEdgeBuilder<SetEdgeIds<S>>where
S::EdgeIds: IsUnset,
Sourcepub fn radius(self, value: LengthUnit) -> Solid3dFilletEdgeBuilder<SetRadius<S>>where
S::Radius: IsUnset,
pub fn radius(self, value: LengthUnit) -> Solid3dFilletEdgeBuilder<SetRadius<S>>where
S::Radius: IsUnset,
Required.
The radius of the fillet. Measured in length (using the same units that the current sketch uses). Must be positive (i.e. greater than zero).
Sourcepub fn tolerance(
self,
value: LengthUnit,
) -> Solid3dFilletEdgeBuilder<SetTolerance<S>>where
S::Tolerance: IsUnset,
pub fn tolerance(
self,
value: LengthUnit,
) -> Solid3dFilletEdgeBuilder<SetTolerance<S>>where
S::Tolerance: IsUnset,
Required.
The maximum acceptable surface gap computed between the filleted surfaces. Must be positive (i.e. greater than zero).
Sourcepub fn cut_type(self, value: CutType) -> Solid3dFilletEdgeBuilder<SetCutType<S>>where
S::CutType: IsUnset,
pub fn cut_type(self, value: CutType) -> Solid3dFilletEdgeBuilder<SetCutType<S>>where
S::CutType: IsUnset,
Sourcepub fn maybe_cut_type(
self,
value: Option<CutType>,
) -> Solid3dFilletEdgeBuilder<SetCutType<S>>where
S::CutType: IsUnset,
pub fn maybe_cut_type(
self,
value: Option<CutType>,
) -> Solid3dFilletEdgeBuilder<SetCutType<S>>where
S::CutType: IsUnset,
Sourcepub fn strategy(
self,
value: CutStrategy,
) -> Solid3dFilletEdgeBuilder<SetStrategy<S>>where
S::Strategy: IsUnset,
pub fn strategy(
self,
value: CutStrategy,
) -> Solid3dFilletEdgeBuilder<SetStrategy<S>>where
S::Strategy: IsUnset,
Sourcepub fn maybe_strategy(
self,
value: Option<CutStrategy>,
) -> Solid3dFilletEdgeBuilder<SetStrategy<S>>where
S::Strategy: IsUnset,
pub fn maybe_strategy(
self,
value: Option<CutStrategy>,
) -> Solid3dFilletEdgeBuilder<SetStrategy<S>>where
S::Strategy: IsUnset,
Sourcepub fn extra_face_ids(
self,
value: Vec<Uuid>,
) -> Solid3dFilletEdgeBuilder<SetExtraFaceIds<S>>where
S::ExtraFaceIds: IsUnset,
pub fn extra_face_ids(
self,
value: Vec<Uuid>,
) -> Solid3dFilletEdgeBuilder<SetExtraFaceIds<S>>where
S::ExtraFaceIds: IsUnset,
Optional (Some / Option setters).
Default: <Vec<Uuid> as Default>::default().
What IDs should the resulting faces have?
If you’ve only passed one edge ID, its ID will
be the command ID used to send this command, and this
field should be empty.
If you’ve passed n IDs (to fillet n edges), then
this should be length n-1, and the first edge will use
the command ID used to send this command.
Sourcepub fn maybe_extra_face_ids(
self,
value: Option<Vec<Uuid>>,
) -> Solid3dFilletEdgeBuilder<SetExtraFaceIds<S>>where
S::ExtraFaceIds: IsUnset,
pub fn maybe_extra_face_ids(
self,
value: Option<Vec<Uuid>>,
) -> Solid3dFilletEdgeBuilder<SetExtraFaceIds<S>>where
S::ExtraFaceIds: IsUnset,
Optional (Some / Option setters).
Default: <Vec<Uuid> as Default>::default().
What IDs should the resulting faces have?
If you’ve only passed one edge ID, its ID will
be the command ID used to send this command, and this
field should be empty.
If you’ve passed n IDs (to fillet n edges), then
this should be length n-1, and the first edge will use
the command ID used to send this command.
Sourcepub fn use_legacy(
self,
value: bool,
) -> Solid3dFilletEdgeBuilder<SetUseLegacy<S>>where
S::UseLegacy: IsUnset,
pub fn use_legacy(
self,
value: bool,
) -> Solid3dFilletEdgeBuilder<SetUseLegacy<S>>where
S::UseLegacy: IsUnset,
Sourcepub fn maybe_use_legacy(
self,
value: Option<bool>,
) -> Solid3dFilletEdgeBuilder<SetUseLegacy<S>>where
S::UseLegacy: IsUnset,
pub fn maybe_use_legacy(
self,
value: Option<bool>,
) -> Solid3dFilletEdgeBuilder<SetUseLegacy<S>>where
S::UseLegacy: IsUnset,